==> ilund4u-0.0.2.1.tar.gz: ilund4u-0.0.2.1/docs/pypi.md <==


<img  src="https://raw.githubusercontent.com/art-egorov/iLund4u/main/docs/img/ilund4u_logo.png?token=GHSAT0AAAAAACNA6ZUMHKXAJEHFEYINLXQ2ZTK4Y3Q" width="310"/>

## Description

**iLund4u** is a bioinformatics tool for search and annotation of hotspots in a large set of proteomes. 

**Supported input**: gff3 with sequence (prokka/pharokka produced)      
**Programming language:** Python3   
**OS:** MacOS, Linux  
**Python dependencies:** biopython, bcbio-gff, scipy, configs, argparse, pandas, matplotlib, seaborn, progess, leidanalg, igraph. pyhmmer, msa4u, lovis4u    
**Python version:** >= 3.8  
**OS-level dependencies:** MMseqs2 (included in the package)  
**License:** WTFPL  
**Version:** 0.0.2 (June 2024)

**Detailed documentation with user guide is available at [iLund4u Homepage](https://art-egorov.github.io/iLund4u/)**

## Reference 📃

If you find iLund4u useful, please cite:  
Artyom. A. Egorov, Gemma C. Atkinson, **iLund4u: ---**, *---*

## Contact 📇

Please contact us by e-mail _artem**dot**egorov**AT**med**dot**lu**dot**se_ or use [Issues](https://github.com/art-egorov/ilund4u/issues?q=) to report any technical problems.  
You can also use [Discussions section](https://github.com/art-egorov/ilund4u/discussions) for sharing your ideas or feature requests! 

## Authors 👨🏻‍💻

iLund4u is developed by Artyom Egorov at [the Atkinson Lab](https://atkinson-lab.com), Department of Experimental Medical Science, Lund University, Sweden. We are open for suggestions to extend and improve iLund4u functionality. Please don't hesitate to share your ideas or feature requests.

==> ilund4u-0.0.3.0.tar.gz: ilund4u-0.0.3.0/docs/pypi.md <==


<img  src="https://raw.githubusercontent.com/art-egorov/iLund4u/main/docs/img/ilund4u_logo.png?token=GHSAT0AAAAAACNA6ZUMHKXAJEHFEYINLXQ2ZTK4Y3Q" width="310"/>

## Description

**iLund4u** is a bioinformatics tool for search and annotation of hotspots in a large set of proteomes. 

**Supported input**: gff3 for annotation files (prokka/pharokka generated); fasta for protein sequences        
**Programming language:** Python3   
**OS:** MacOS, Linux  
**Python dependencies:** biopython, bcbio-gff, scipy, configs, argparse, pandas, matplotlib, seaborn, progess, leidanalg, igraph. pyhmmer, msa4u, lovis4u    
**Python version:** >= 3.8  
**OS-level dependencies:** MMseqs2 (included in the package)  
**License:** WTFPL  
**Version:** 0.0.3 (June 2024)


**Detailed documentation with user guide is available at [iLund4u Homepage](https://art-egorov.github.io/ilund4u/)**

## Reference 📃

If you find iLund4u useful, please cite:  
Artyom. A. Egorov, Gemma C. Atkinson, **iLund4u: ---**, *---*

## Contact 📇

Please contact us by e-mail _artem**dot**egorov**AT**med**dot**lu**dot**se_ or use [Issues](https://github.com/art-egorov/ilund4u/issues?q=) to report any technical problems.  
You can also use [Discussions section](https://github.com/art-egorov/ilund4u/discussions) for sharing your ideas or feature requests! 

## Authors 👨🏻‍💻

iLund4u is developed by Artyom Egorov at [the Atkinson Lab](https://atkinson-lab.com), Department of Experimental Medical Science, Lund University, Sweden. We are open for suggestions to extend and improve iLund4u functionality. Please don't hesitate to share your ideas or feature requests.
